@@ -15,18 +15,19 @@ def main():
     args = parser.parse_args()
 
     if(args.single=="True"):
-            print(args.single)
             if(args.re!=None):
                 result=SimpleSpider.SinglePageGetByRegEx(Url=args.url,RegEx=args.re)
                 if(args.print=="True"):
-                    print(result)
+                    for i in result:
+                        print(i)
                 if (args.output != None):
                     SimpleSpider.ExportFileToExcel(result, args.output)
 
             else:
                 result=SimpleSpider.SinglePageGetByXpath(Url=args.url,Xpath=args.xpath)
                 if (args.print == "True"):
-                    print(result)
+                    for i in result:
+                        print(i)
 
                 if(args.output!=None):
                     SimpleSpider.ExportFileToExcel(result,args.output)
@@ -36,12 +37,14 @@ def main():
 
             result = SimpleSpider.MulityPageGetByRegEx(Url=args.url, IndexList=indexlist, RegEx=args.re)
             if (args.print == "True"):
-                print(result)
+                for i in result:
+                    print(i)
             if (args.output != None):
                 SimpleSpider.ExportFileToExcel(result, args.output)
         else:
             result = SimpleSpider.MulityPageGetByXpath(Url=args.url, IndexList=indexlist, RegEx=args.re)
             if (args.print == "True"):
-                print(result)
+                for i in result:
+                    print(i)
             if (args.output != None):
                 SimpleSpider.ExportFileToExcel(result, args.output)
\ No newline at end of file
